@@ -1017,75 +1017,3 @@ SEXP cpp_unlist_group_locs(SEXP x){
 //   Rf_unprotect(4);
 //   return out;
 // }
-
-// Taken from cheapr, will remove in future
-
-[[cpp11::register]]
-SEXP cpp_set_replace(SEXP x, SEXP where, SEXP what){
-  if (TYPEOF(x) != TYPEOF(what)){
-    Rf_error("`typeof(x)` must match `typeof(what)`");
-  }
-  int *p_where = INTEGER(where);
-
-  if (ALTREP(x)){
-    Rf_warning("Cannot update an ALTREP by reference, a copy has been made.\n\tEnsure the result is assigned to an object if used in further calculations");
-  }
-  Rf_protect(x = (ALTREP(x) ? Rf_duplicate(x) : x));
-
-  long long int xn = Rf_xlength(x);
-  int where_size = Rf_length(where);
-  int what_size = Rf_length(what);
-  if (what_size != 1 && where_size != what_size){
-    Rf_unprotect(1);
-    Rf_error("`what` must be either length 1 or `length(where)`");
-  }
-  long long int xi;
-
-
-#define FASTPLYR_REPLACE                                                                           \
-  if (what_size == 1){                                                                           \
-    for (int i = 0; i < where_size; ++i){                                                        \
-      xi = p_where[i];                                                                           \
-      if (xi <= 0 || xi > xn){                                                                   \
-        Rf_unprotect(1);                                                                         \
-        Rf_error("where must be an integer vector of values between 1 and `length(x)`");         \
-      }                                                                                          \
-      p_x[xi - 1] = p_what[0];                                                                   \
-    }                                                                                            \
-  } else {                                                                                       \
-    for (int i = 0; i < where_size; ++i){                                                        \
-      xi = p_where[i];                                                                           \
-      if (xi <= 0 || xi > xn){                                                                   \
-        Rf_unprotect(1);                                                                         \
-        Rf_error("where must be an integer vector of values between 1 and `length(x)`");         \
-      }                                                                                          \
-      p_x[xi - 1] = p_what[i];                                                                   \
-    }                                                                                            \
-  }                                                                                              \
-
-
-switch (TYPEOF(x)){
-case NILSXP: {
-  break;
-}
-case LGLSXP:
-case INTSXP: {
-  int *p_x = INTEGER(x);
-  int *p_what = INTEGER(what);
-  FASTPLYR_REPLACE
-  break;
-}
-case REALSXP: {
-  double *p_x = REAL(x);
-  double *p_what = REAL(what);
-  FASTPLYR_REPLACE
-  break;
-}
-default: {
-  Rf_unprotect(1);
-  Rf_error("%s cannot handle an object of type %s", __func__, Rf_type2char(TYPEOF(x)));
-}
-}
-  Rf_unprotect(1);
-  return x;
-}
